;; Generated package description from gnugo.el  -*- no-byte-compile: t -*-
(define-package "gnugo" "3.1.2.0.20230911.4426" "play GNU Go in a buffer" '((ascii-art-to-unicode "1.5") (xpm "1.0.1") (cl-lib "0.5")) :commit "a9b2979c20258b00c49f9932a5eac104bab1124e" :authors '(("Thien-Thi Nguyen" . "ttn@gnu.org")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("games" "processes") :url "https://www.gnuvola.org/software/gnugo/")
